@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2007 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006-2007 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef SHAPESHEARSTRATEGY_H
@@ -29,6 +16,7 @@
 
 class KoToolBase;
 class KoShape;
+class KoSelection;
 
 /**
  * A strategy for the KoInteractionTool.
@@ -44,7 +32,7 @@ public:
      * @param clicked the initial point that the user depressed (in pt).
      * @param direction the handle that was grabbed
      */
-    ShapeShearStrategy(KoToolBase *tool, const QPointF &clicked, KoFlake::SelectionHandle direction);
+    ShapeShearStrategy(KoToolBase *tool, KoSelection *selection, const QPointF &clicked, KoFlake::SelectionHandle direction);
     ~ShapeShearStrategy() override {}
 
     void handleMouseMove(const QPointF &mouseLocation, Qt::KeyboardModifiers modifiers) override;
@@ -59,10 +47,13 @@ private:
     QPointF m_start;
     QPointF m_solidPoint;
     QSizeF m_initialSize;
-    bool m_top, m_left, m_bottom, m_right;
-    qreal m_initialSelectionAngle;
+    bool m_top {false};
+    bool m_left {false};
+    bool m_bottom {false};
+    bool m_right {false};
+    qreal m_initialSelectionAngle {0.0};
     QTransform m_shearMatrix;
-    bool m_isMirrored;
+    bool m_isMirrored {false};
     QList<QTransform> m_oldTransforms;
     QList<KoShape *> m_transformedShapesAndSelection;
 };
